@@ -36,7 +36,7 @@ sub header_filter {
         }->()
     );
     if (Scalar::Util::blessed($res)) {
-        $res->header( 'Set-Cookie' => $cookie->as_string );
+        $res->headers->push_header( 'Set-Cookie' => $cookie->as_string );
         $res;
     } else {
         push @{$res->[1]}, 'Set-Cookie' => $cookie->as_string;
@@ -44,4 +44,4 @@ sub header_filter {
     }
 }
 
-1;
\ No newline at end of file
+1;
